@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
-from clu.constants import Enum, EnumMeta
+
+from clu.constants.polyfills import Enum, EnumMeta
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
     
 # Dunder and sunder name constants for the alias dict:
-DUNDER = '__alias__'
-SUNDER = '_alias_'
+DUNDER = '__aliases__'
+SUNDER = '_aliases_'
 
 @export
 class alias(object):
@@ -93,7 +94,7 @@ class alias(object):
         self.name = name
         if hasattr(cls, '__aliases__'):
             if self.name in cls.__aliases__:
-                message = "Enum already contains an alias named %s" % self.name
+                message = f"Enum already contains an alias named {self.name}"
                 raise AttributeError(message)
             cls.__aliases__[self.name] = self.member_for_value(cls, self.aliased)
 
@@ -130,9 +131,5 @@ class AliasingEnum(Enum, metaclass=AliasingEnumMeta):
     """
     pass
 
-# NO DOCS ALLOWED:
-export(DUNDER,          name='DUNDER')
-export(SUNDER,          name='SUNDER')
-
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
-__all__, __dir__ = exporter.all_and_dir()
\ No newline at end of file
+__all__, __dir__ = exporter.all_and_dir()
